Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1642)

Unified Diff: chrome/browser/extensions/extension_service.h

Issue 10854009: Extension white and force lists (set by policy) should have priority over auto-updated Google black… (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Refactored Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/extension_service.h
diff --git a/chrome/browser/extensions/extension_service.h b/chrome/browser/extensions/extension_service.h
index c326490a1a8cb6f32e3d039fe3a0dcb5e02b4897..08b31e6630c2f17e1a3e2cb7ca1baabfb7d01766 100644
--- a/chrome/browser/extensions/extension_service.h
+++ b/chrome/browser/extensions/extension_service.h
@@ -121,7 +121,7 @@ class ExtensionServiceInterface : public syncer::SyncableService {
virtual void UpdateExtensionBlacklist(
const std::vector<std::string>& blacklist) = 0;
- virtual void CheckAdminBlacklist() = 0;
+ virtual void CheckManagementPolicy() = 0;
// Safe to call multiple times in a row.
//
@@ -413,10 +413,10 @@ class ExtensionService
virtual void UpdateExtensionBlacklist(
const std::vector<std::string>& blacklist) OVERRIDE;
- // Go through each extension and unload those that the network admin has
- // put on the blacklist (not to be confused with the Google-managed blacklist)
- // set of extensions.
- virtual void CheckAdminBlacklist() OVERRIDE;
+ // Go through each extension and unload those that are not allowed to run by
+ // management policy providers (ie. network admin and Google-managed
+ // blacklist).
+ virtual void CheckManagementPolicy() OVERRIDE;
virtual void CheckForUpdatesSoon() OVERRIDE;

Powered by Google App Engine
This is Rietveld 408576698